from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Interface_Optical = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'IS471F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS471F'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Sharp_IS471F'], 'footprint':'OptoDevice:Sharp_IS471F', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.micropik.com/PDF/tsop17xx.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nIS471F\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GLo',func=pin_types.OPENCOLL,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS485', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS485'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Sharp_IS485'], 'footprint':'OptoDevice:Sharp_IS485', 'keywords':'opto receiver amplifier light detector OPIC', 'description':'', 'datasheet':'https://media.digikey.com/pdf/Data%20Sheets/Sharp%20PDFs/is485,486_e.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nIS485\n\nopto receiver amplifier light detector OPIC', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS486', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS486'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Sharp_IS485'], 'footprint':'OptoDevice:Sharp_IS485', 'keywords':'opto receiver amplifier light detector OPIC', 'description':'', 'datasheet':'https://media.digikey.com/pdf/Data%20Sheets/Sharp%20PDFs/is485,486_e.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nIS486\n\nopto receiver amplifier light detector OPIC', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'QSE159', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'QSE159'}), 'ref_prefix':'U', 'fplist':['OptoDevice:ONSemi_QSE15x'], 'footprint':'OptoDevice:ONSemi_QSE15x', 'keywords':'opto IR', 'description':'', 'datasheet':'http://www.onsemi.com/pub/Collateral/QSE159-D.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nQSE159\n\nopto IR', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Out',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='Vcc',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SFP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SFP'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'SFP transceiver gigabit ethernet INF-8074i', 'description':'', 'datasheet':'http://www.10gtek.com/templates/wzten/pdf/INF-8074.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nSFP\n\nSFP transceiver gigabit ethernet INF-8074i', 'pins':[
            Pin(num='1',name='VeeT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VeeR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VeeR',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='RD-',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='RD+',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VeeR',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VccR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VccT',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VeeT',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='TD+',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='TD-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='TX_FAULT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='20',name='VeeT',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TX_DISABLE',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='MOD_DEF2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='MOD_DEF1',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='MOD_DEF0',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RATE_SELECT',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RX_LOS',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='VeeR',func=pin_types.PASSIVE,unit=1),
            Pin(num='CAGE',name='CAGE',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SFP+', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SFP+'}), 'ref_prefix':'J', 'fplist':[''], 'footprint':'', 'keywords':'SFP transceiver gigabit ethernet SFF-8432', 'description':'', 'datasheet':'https://members.snia.org/document/dl/25892', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nSFP+\n\nSFP transceiver gigabit ethernet SFF-8432', 'pins':[
            Pin(num='1',name='VeeT',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VeeR',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VeeR',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='RD-',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='RD+',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VeeR',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='VccR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VccT',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='VeeT',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='TD+',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='TD-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='TX_FAULT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='20',name='VeeT',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TX_DISABLE',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='MOD_ABS',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='RS0',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RX_LOS',func=pin_types.OPENCOLL,unit=1),
            Pin(num='9',name='RS1',func=pin_types.INPUT,unit=1),
            Pin(num='CAGE',name='CAGE',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSDP341xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSDP341xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82667/tsdp341.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSDP341xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSMP58138', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSMP58138'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINICAST-3Pin'], 'footprint':'OptoDevice:Vishay_MINICAST-3Pin', 'keywords':'opto IR repeater receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82486/tsmp58138.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSMP58138\n\nopto IR repeater receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP17xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP17xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_CAST-3Pin'], 'footprint':'OptoDevice:Vishay_CAST-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.micropik.com/PDF/tsop17xx.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP17xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP32S40F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP32S40F'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82669/tsop32s40f.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP32S40F\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP331xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP331xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINIMOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MINIMOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82742/tsop331.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP331xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP34S40F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP34S40F'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82669/tsop32s40f.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP34S40F\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP581xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP581xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINICAST-3Pin'], 'footprint':'OptoDevice:Vishay_MINICAST-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82462/tsop581.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP581xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSDP343xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSDP343xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82667/tsdp341.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSDP343xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSMP58000', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSMP58000'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin'], 'footprint':'OptoDevice:Vishay_MINICAST-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82485/tsmp58000.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSMP58000\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP21xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP21xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82460/tsop45.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP21xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP23xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP23xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82460/tsop45.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP23xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP25xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP25xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82460/tsop45.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP25xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP312xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP312xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_CAST-3Pin', 'OptoDevice:Vishay_CAST-3Pin'], 'footprint':'OptoDevice:Vishay_CAST-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82492/tsop312.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP312xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP314xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP314xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_CAST-3Pin', 'OptoDevice:Vishay_CAST-3Pin', 'OptoDevice:Vishay_CAST-3Pin'], 'footprint':'OptoDevice:Vishay_CAST-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82492/tsop312.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP314xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='OUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP321xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP321xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82490/tsop321.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP321xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP323xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP323xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82490/tsop321.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP323xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP325xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP325xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82490/tsop321.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP325xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP333xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP333xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINIMOLD-3Pin', 'OptoDevice:Vishay_MINIMOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MINIMOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82742/tsop331.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP333xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP335xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP335xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINIMOLD-3Pin', 'OptoDevice:Vishay_MINIMOLD-3Pin', 'OptoDevice:Vishay_MINIMOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MINIMOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82742/tsop331.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP335xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP341xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP341xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82490/tsop321.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP341xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP343xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP343xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82490/tsop321.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP343xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP345xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP345xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82490/tsop321.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP345xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP348xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP348xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'https://www.vishay.com/docs/82489/tsop322.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP348xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP382xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP382xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin'], 'footprint':'OptoDevice:Vishay_MINICAST-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82491/tsop382.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP382xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP384xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP384xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin'], 'footprint':'OptoDevice:Vishay_MINICAST-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82491/tsop382.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP384xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP38G36', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP38G36'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin'], 'footprint':'OptoDevice:Vishay_MINICAST-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82731/tsop38g36.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP38G36\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP41xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP41xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82460/tsop45.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP41xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP43xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP43xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82460/tsop45.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP43xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP45xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP45xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin', 'OptoDevice:Vishay_MOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82460/tsop45.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP45xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP531xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP531xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINIMOLD-3Pin', 'OptoDevice:Vishay_MINIMOLD-3Pin', 'OptoDevice:Vishay_MINIMOLD-3Pin', 'OptoDevice:Vishay_MINIMOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MINIMOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82745/tsop531.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP531xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP533xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP533xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINIMOLD-3Pin', 'OptoDevice:Vishay_MINIMOLD-3Pin', 'OptoDevice:Vishay_MINIMOLD-3Pin', 'OptoDevice:Vishay_MINIMOLD-3Pin', 'OptoDevice:Vishay_MINIMOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MINIMOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82745/tsop531.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP533xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP535xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP535xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINIMOLD-3Pin', 'OptoDevice:Vishay_MINIMOLD-3Pin', 'OptoDevice:Vishay_MINIMOLD-3Pin', 'OptoDevice:Vishay_MINIMOLD-3Pin', 'OptoDevice:Vishay_MINIMOLD-3Pin', 'OptoDevice:Vishay_MINIMOLD-3Pin'], 'footprint':'OptoDevice:Vishay_MINIMOLD-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82745/tsop531.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP535xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP582xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP582xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin'], 'footprint':'OptoDevice:Vishay_MINICAST-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82461/tsop582.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP582xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP583xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP583xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin'], 'footprint':'OptoDevice:Vishay_MINICAST-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82462/tsop581.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP583xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP584xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP584xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin'], 'footprint':'OptoDevice:Vishay_MINICAST-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82461/tsop582.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP584xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TSOP585xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TSOP585xx'}), 'ref_prefix':'U', 'fplist':['OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin', 'OptoDevice:Vishay_MINICAST-3Pin'], 'footprint':'OptoDevice:Vishay_MINICAST-3Pin', 'keywords':'opto IR receiver', 'description':'', 'datasheet':'http://www.vishay.com/docs/82462/tsop581.pdf', 'search_text':'/usr/share/kicad/symbols/Interface_Optical.kicad_sym\nTSOP585xx\n\nopto IR receiver', 'pins':[
            Pin(num='1',name='OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

RF_WiFi = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'HF-A11-SMT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HF-A11-SMT'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'WiFi IEEE802.11 b/g/n', 'description':'', 'datasheet':'http://www.hi-flying.com/index.php?route=tool/upload/download&code=190ec6c62d497905ed783d140f8e5af7a753b8ab', 'search_text':'/usr/share/kicad/symbols/RF_WiFi.kicad_sym\nHF-A11-SMT\n\nWiFi IEEE802.11 b/g/n', 'pins':[
            Pin(num='1',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='RX+',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='RX-',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='~{LINK}',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='~{READY}',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='~{RELOAD}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='3.3V',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='UART1_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='UART1_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='1.8VOUT',func=pin_types.PWROUT,unit=1),
            Pin(num='24',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='RF',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='UART_TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='UART_RXD',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='UART_RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='UART_CTS',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='TX+',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='TX-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'USR-C322', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'USR-C322'}), 'ref_prefix':'U', 'fplist':['RF_WiFi:USR-C322'], 'footprint':'RF_WiFi:USR-C322', 'keywords':'WiFi IEEE802.11 b/g/n', 'description':'', 'datasheet':'https://www.usriot.com/download/WIFI/USR-C322%20User%20Manual%20V2.3.pdf', 'search_text':'/usr/share/kicad/symbols/RF_WiFi.kicad_sym\nUSR-C322\n\nWiFi IEEE802.11 b/g/n', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='VBT_CC',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VDD_ANA2',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='GPIO3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='UART0_TX',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GPIO0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='UART0_RX',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='~{RELOAD}',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='~{READY}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='23',name='~{LINK}',func=pin_types.OPENCOLL,unit=1),
            Pin(num='24',name='UART0_CTS',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='UART0_RTS',func=pin_types.OUTPUT,unit=1),
            Pin(num='26',name='GPIO4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='GPIO5',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='UART1_TX',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='UART1_RX',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='GPIO6',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GPIO7',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='GPIO8',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='GPIO9',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='GPIO10',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='GPIO11',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='GPIO12',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='GPIO13',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='43',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='SOP2',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='SOP1',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='SOP0',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='ANA_DC-DC',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Transistor_Array = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'A2982', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'A2982'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm'], 'footprint':'Package_SO:SOIC-20W_7.5x12.8mm_P1.27mm', 'keywords':'relays solenoids lamps steppers servos LEDs', 'description':'', 'datasheet':'https://www.allegromicro.com/~/media/Files/Datasheets/A2981-2-Datasheet.ashx', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nA2982\n\nrelays solenoids lamps steppers servos LEDs', 'pins':[
            Pin(num='1',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='OUT8',func=pin_types.OPENEMIT,unit=1),
            Pin(num='14',name='OUT7',func=pin_types.OPENEMIT,unit=1),
            Pin(num='15',name='OUT6',func=pin_types.OPENEMIT,unit=1),
            Pin(num='16',name='OUT5',func=pin_types.OPENEMIT,unit=1),
            Pin(num='17',name='OUT4',func=pin_types.OPENEMIT,unit=1),
            Pin(num='18',name='OUT3',func=pin_types.OPENEMIT,unit=1),
            Pin(num='19',name='OUT2',func=pin_types.OPENEMIT,unit=1),
            Pin(num='2',name='IN2',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='OUT1',func=pin_types.OPENEMIT,unit=1),
            Pin(num='3',name='IN3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='IN5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IN6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='IN7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='+VS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC1413D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC1413D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MC1413-D.PDF', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nMC1413D\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN75468', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN75468'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/slrs023e/slrs023e.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nSN75468\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBD62783A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBD62783A'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'relays solenoids lamps steppers servos LEDs', 'description':'', 'datasheet':'http://toshiba.semicon-storage.com/info/docget.jsp?did=30523&prodName=TBD62783APG', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nTBD62783A\n\nrelays solenoids lamps steppers servos LEDs', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='O8',func=pin_types.OPENEMIT,unit=1),
            Pin(num='12',name='O7',func=pin_types.OPENEMIT,unit=1),
            Pin(num='13',name='O6',func=pin_types.OPENEMIT,unit=1),
            Pin(num='14',name='O5',func=pin_types.OPENEMIT,unit=1),
            Pin(num='15',name='O4',func=pin_types.OPENEMIT,unit=1),
            Pin(num='16',name='O3',func=pin_types.OPENEMIT,unit=1),
            Pin(num='17',name='O2',func=pin_types.OPENEMIT,unit=1),
            Pin(num='18',name='O1',func=pin_types.OPENEMIT,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBD62785APG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBD62785APG'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-18_W7.62mm'], 'footprint':'Package_DIP:DIP-18_W7.62mm', 'keywords':'relays solenoids lamps steppers servos LEDs', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/TBD62785APG_datasheet_en_20170530.pdf?did=58399&prodName=TBD62785APG', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nTBD62785APG\n\nrelays solenoids lamps steppers servos LEDs', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='O8',func=pin_types.OPENEMIT,unit=1),
            Pin(num='12',name='O7',func=pin_types.OPENEMIT,unit=1),
            Pin(num='13',name='O6',func=pin_types.OPENEMIT,unit=1),
            Pin(num='14',name='O5',func=pin_types.OPENEMIT,unit=1),
            Pin(num='15',name='O4',func=pin_types.OPENEMIT,unit=1),
            Pin(num='16',name='O3',func=pin_types.OPENEMIT,unit=1),
            Pin(num='17',name='O2',func=pin_types.OPENEMIT,unit=1),
            Pin(num='18',name='O1',func=pin_types.OPENEMIT,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ULN2003', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ULN2003'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/uln2003a.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nULN2003\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ULN2803A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ULN2803A'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Darlington transistor array', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/uln2803a.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nULN2803A\n\nDarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='O8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ULQ2003A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ULQ2003A'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/uln2003a.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nULQ2003A\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC1413BD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC1413BD'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MC1413-D.PDF', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nMC1413BD\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC1413BP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC1413BP'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_DIP:DIP-16_W7.62mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MC1413-D.PDF', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nMC1413BP\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MC1413P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MC1413P'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_DIP:DIP-16_W7.62mm', 'Package_DIP:DIP-16_W7.62mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MC1413-D.PDF', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nMC1413P\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NCV1413B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NCV1413B'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_DIP:DIP-16_W7.62mm', 'Package_DIP:DIP-16_W7.62mm', 'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.onsemi.com/pub_link/Collateral/MC1413-D.PDF', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nNCV1413B\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SN75469', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SN75469'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/slrs023e/slrs023e.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nSN75469\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TBD62785AFWG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TBD62785AFWG'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-18_W7.62mm', 'Package_SO:SOP-18_7.495x11.515mm_P1.27mm'], 'footprint':'Package_DIP:DIP-18_W7.62mm', 'keywords':'relays solenoids lamps steppers servos LEDs', 'description':'', 'datasheet':'https://toshiba.semicon-storage.com/info/TBD62785AFWG_datasheet_en_20170530.pdf?did=58399&prodName=TBD62785AFWG', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nTBD62785AFWG\n\nrelays solenoids lamps steppers servos LEDs', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='O8',func=pin_types.OPENEMIT,unit=1),
            Pin(num='12',name='O7',func=pin_types.OPENEMIT,unit=1),
            Pin(num='13',name='O6',func=pin_types.OPENEMIT,unit=1),
            Pin(num='14',name='O5',func=pin_types.OPENEMIT,unit=1),
            Pin(num='15',name='O4',func=pin_types.OPENEMIT,unit=1),
            Pin(num='16',name='O3',func=pin_types.OPENEMIT,unit=1),
            Pin(num='17',name='O2',func=pin_types.OPENEMIT,unit=1),
            Pin(num='18',name='O1',func=pin_types.OPENEMIT,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VCC',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ULN2002', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ULN2002'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/uln2003a.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nULN2002\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ULN2002A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ULN2002A'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/uln2003a.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nULN2002A\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ULN2003A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ULN2003A'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/uln2003a.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nULN2003A\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ULN2004', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ULN2004'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/uln2003a.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nULN2004\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ULN2004A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ULN2004A'}), 'ref_prefix':'U', 'fplist':['', '', '', '', '', ''], 'footprint':'', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/uln2003a.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nULN2004A\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ULN2801A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ULN2801A'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.promelec.ru/pdf/1536.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nULN2801A\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='O8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ULN2802A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ULN2802A'}), 'ref_prefix':'U', 'fplist':['', '', ''], 'footprint':'', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.promelec.ru/pdf/1536.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nULN2802A\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='O8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ULN2804A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ULN2804A'}), 'ref_prefix':'U', 'fplist':['', '', '', ''], 'footprint':'', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.promelec.ru/pdf/1536.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nULN2804A\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='O8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ULN2805A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ULN2805A'}), 'ref_prefix':'U', 'fplist':['', '', '', '', ''], 'footprint':'', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.promelec.ru/pdf/1536.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nULN2805A\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='O8',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='17',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='18',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='I8',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ULQ2004A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ULQ2004A'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'darlington transistor array', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/uln2003a.pdf', 'search_text':'/usr/share/kicad/symbols/Transistor_Array.kicad_sym\nULQ2004A\n\ndarlington transistor array', 'pins':[
            Pin(num='1',name='I1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='O7',func=pin_types.OPENCOLL,unit=1),
            Pin(num='11',name='O6',func=pin_types.OPENCOLL,unit=1),
            Pin(num='12',name='O5',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='O4',func=pin_types.OPENCOLL,unit=1),
            Pin(num='14',name='O3',func=pin_types.OPENCOLL,unit=1),
            Pin(num='15',name='O2',func=pin_types.OPENCOLL,unit=1),
            Pin(num='16',name='O1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='2',name='I2',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='I3',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='I4',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='I5',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='I6',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='I7',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

FPGA_Efinix_Trion = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'T8Q144xx', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'T8Q144xx'}), 'ref_prefix':'U', 'fplist':['Package_QFP:LQFP-144_20x20mm_P0.5mm'], 'footprint':'Package_QFP:LQFP-144_20x20mm_P0.5mm', 'keywords':'FPGA programmable logic', 'description':'', 'datasheet':'https://www.efinixinc.com/docs/trion8-ds-v4.4.pdf', 'search_text':'/usr/share/kicad/symbols/FPGA_Efinix_Trion.kicad_sym\nT8Q144xx\n\nFPGA programmable logic', 'pins':[
            Pin(num='23',name='VCCIO1A',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='TDO',func=pin_types.OUTPUT,unit=1),
            Pin(num='25',name='TMS',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='TCK',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='TDI',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='GPIOL_09_CDI1',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='GPIOL_08_CDI0',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='GPIOL_01_CCK',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='GPIOL_00_SS_N',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='GPIOL_04_CSI',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GPIOL_05_CSO',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='CDONE',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='CRESET_N',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='GPIOL_25_CLK1',func=pin_types.BIDIR,unit=2),
            Pin(num='15',name='GPIOL_24_CLK0',func=pin_types.BIDIR,unit=2),
            Pin(num='16',name='GPIOL_22_CTRL2',func=pin_types.BIDIR,unit=2),
            Pin(num='17',name='GPIOL_21_CTRL1_CDI5',func=pin_types.BIDIR,unit=2),
            Pin(num='18',name='GPIOL_20_CTRL0_CDI4',func=pin_types.BIDIR,unit=2),
            Pin(num='19',name='GPIOL_13_CDI3',func=pin_types.BIDIR,unit=2),
            Pin(num='20',name='GPIOL_12_CDI2',func=pin_types.BIDIR,unit=2),
            Pin(num='21',name='VCCIO1B',func=pin_types.PWRIN,unit=2),
            Pin(num='10',name='GPIOL_32_CTRL4_CDI7',func=pin_types.BIDIR,unit=3),
            Pin(num='11',name='GPIOL_31_CLK7_CDI6',func=pin_types.BIDIR,unit=3),
            Pin(num='12',name='VCCIO1C_1D',func=pin_types.PWRIN,unit=3),
            Pin(num='3',name='GPIOL_53_CDI10',func=pin_types.BIDIR,unit=3),
            Pin(num='4',name='GPIOL_54_CDI11',func=pin_types.BIDIR,unit=3),
            Pin(num='6',name='GPIOL_46',func=pin_types.BIDIR,unit=3),
            Pin(num='7',name='GPIOL_41_CDI9',func=pin_types.BIDIR,unit=3),
            Pin(num='8',name='GPIOL_40_CDI8',func=pin_types.BIDIR,unit=3),
            Pin(num='131',name='GPIOL_75_PLLIN1',func=pin_types.BIDIR,unit=4),
            Pin(num='132',name='GPIOL_74_PLLIN0',func=pin_types.BIDIR,unit=4),
            Pin(num='134',name='GPIOL_73_EXTFB1_CDI15',func=pin_types.BIDIR,unit=4),
            Pin(num='135',name='GPIOL_72_EXTFB0_CDI14',func=pin_types.BIDIR,unit=4),
            Pin(num='136',name='GPIOL_71_NSTATUS',func=pin_types.BIDIR,unit=4),
            Pin(num='137',name='GPIOL_70_CBSEL0',func=pin_types.BIDIR,unit=4),
            Pin(num='138',name='GPIOL_69_CBSEL1',func=pin_types.BIDIR,unit=4),
            Pin(num='139',name='GPIOL_68',func=pin_types.BIDIR,unit=4),
            Pin(num='140',name='GPIOL_67_CDI13',func=pin_types.BIDIR,unit=4),
            Pin(num='141',name='GPIOL_65',func=pin_types.BIDIR,unit=4),
            Pin(num='142',name='GPIOL_66_CDI12',func=pin_types.BIDIR,unit=4),
            Pin(num='143',name='VCCIO1E',func=pin_types.PWRIN,unit=4),
            Pin(num='144',name='GPIOL_64',func=pin_types.BIDIR,unit=4),
            Pin(num='109',name='GPIOR_88_CDI28',func=pin_types.BIDIR,unit=5),
            Pin(num='110',name='GPIOR_87_CDI29',func=pin_types.BIDIR,unit=5),
            Pin(num='111',name='GPIOR_85',func=pin_types.BIDIR,unit=5),
            Pin(num='112',name='GPIOR_86',func=pin_types.BIDIR,unit=5),
            Pin(num='113',name='GPIOR_84',func=pin_types.BIDIR,unit=5),
            Pin(num='114',name='GPIOR_83',func=pin_types.BIDIR,unit=5),
            Pin(num='115',name='GPIOR_82',func=pin_types.BIDIR,unit=5),
            Pin(num='116',name='GPIOR_81_MREFCLK',func=pin_types.BIDIR,unit=5),
            Pin(num='117',name='GPIOR_80',func=pin_types.BIDIR,unit=5),
            Pin(num='118',name='GPIOR_79_EXTFB1_CDI30',func=pin_types.BIDIR,unit=5),
            Pin(num='119',name='GPIOR_78_EXTFB0_CDI31',func=pin_types.BIDIR,unit=5),
            Pin(num='122',name='VCCIO3A',func=pin_types.PWRIN,unit=5),
            Pin(num='123',name='GPIOR_77_PLLIN1',func=pin_types.BIDIR,unit=5),
            Pin(num='124',name='GPIOR_76_PLLIN0',func=pin_types.BIDIR,unit=5),
            Pin(num='100',name='GPIOR_113_CDI22',func=pin_types.BIDIR,unit=6),
            Pin(num='101',name='GPIOR_112_CDI23',func=pin_types.BIDIR,unit=6),
            Pin(num='102',name='GPIOR_105_CDI24',func=pin_types.BIDIR,unit=6),
            Pin(num='103',name='GPIOR_104_CDI25',func=pin_types.BIDIR,unit=6),
            Pin(num='105',name='GPIOR_95_CDI26',func=pin_types.BIDIR,unit=6),
            Pin(num='106',name='GPIOR_94_CDI27',func=pin_types.BIDIR,unit=6),
            Pin(num='93',name='GPIOR_123_CLK12_CDI20',func=pin_types.BIDIR,unit=6),
            Pin(num='95',name='VCCIO3B_3C',func=pin_types.PWRIN,unit=6),
            Pin(num='97',name='GPIOR_122_CLK13_CDI21',func=pin_types.BIDIR,unit=6),
            Pin(num='98',name='GPIOR_117_CTRL14',func=pin_types.BIDIR,unit=6),
            Pin(num='99',name='GPIOR_116_CTRL15',func=pin_types.BIDIR,unit=6),
            Pin(num='81',name='GPIOR_139',func=pin_types.BIDIR,unit=7),
            Pin(num='82',name='GPIOR_138',func=pin_types.BIDIR,unit=7),
            Pin(num='83',name='GPIOR_136_CDI16',func=pin_types.BIDIR,unit=7),
            Pin(num='84',name='GPIOR_135_CDI17',func=pin_types.BIDIR,unit=7),
            Pin(num='86',name='GPIOR_133_CDI18',func=pin_types.BIDIR,unit=7),
            Pin(num='87',name='GPIOR_132_CDI19',func=pin_types.BIDIR,unit=7),
            Pin(num='89',name='GPIOR_129_CTRL10',func=pin_types.BIDIR,unit=7),
            Pin(num='90',name='GPIOR_128_CTRL11',func=pin_types.BIDIR,unit=7),
            Pin(num='91',name='VCCIO3D',func=pin_types.PWRIN,unit=7),
            Pin(num='92',name='GPIOR_125_CLK10',func=pin_types.BIDIR,unit=7),
            Pin(num='74',name='GPIOR_158_TEST_N',func=pin_types.BIDIR,unit=8),
            Pin(num='75',name='GPIOR_157_PLLIN',func=pin_types.BIDIR,unit=8),
            Pin(num='76',name='GPIOR_155',func=pin_types.BIDIR,unit=8),
            Pin(num='77',name='GPIOR_154',func=pin_types.BIDIR,unit=8),
            Pin(num='78',name='GPIOR_151_CBUS0',func=pin_types.BIDIR,unit=8),
            Pin(num='79',name='GPIOR_150_CBUS1',func=pin_types.BIDIR,unit=8),
            Pin(num='80',name='GPIOR_149_CBUS2',func=pin_types.BIDIR,unit=8),
            Pin(num='88',name='VCCIO3E',func=pin_types.PWRIN,unit=8),
            Pin(num='55',name='GPIOB_RXP00',func=pin_types.BIDIR,unit=9),
            Pin(num='56',name='GPIOB_RXN00',func=pin_types.BIDIR,unit=9),
            Pin(num='58',name='GPIOB_RXP02',func=pin_types.BIDIR,unit=9),
            Pin(num='59',name='GPIOB_RXN02',func=pin_types.BIDIR,unit=9),
            Pin(num='60',name='GPIOB_RXN03',func=pin_types.BIDIR,unit=9),
            Pin(num='61',name='GPIOB_RXP03',func=pin_types.BIDIR,unit=9),
            Pin(num='62',name='VCCIO4A',func=pin_types.PWRIN,unit=9),
            Pin(num='63',name='VCCIO4A',func=pin_types.PASSIVE,unit=9),
            Pin(num='65',name='GPIOB_RXN07',func=pin_types.BIDIR,unit=9),
            Pin(num='66',name='GPIOB_RXP07',func=pin_types.BIDIR,unit=9),
            Pin(num='67',name='GPIOB_RXP10',func=pin_types.BIDIR,unit=9),
            Pin(num='68',name='GPIOB_RXN10',func=pin_types.BIDIR,unit=9),
            Pin(num='69',name='GPIOB_RXN12_EXTFB0',func=pin_types.BIDIR,unit=9),
            Pin(num='70',name='GPIOB_RXP12_EXTFB0',func=pin_types.BIDIR,unit=9),
            Pin(num='71',name='GPIOB_CLKP0',func=pin_types.BIDIR,unit=9),
            Pin(num='72',name='GPIOB_CLKN0',func=pin_types.BIDIR,unit=9),
            Pin(num='36',name='REF_RES',func=pin_types.PASSIVE,unit=10),
            Pin(num='38',name='GPIOB_TXP00',func=pin_types.BIDIR,unit=10),
            Pin(num='39',name='GPIOB_TXN00',func=pin_types.BIDIR,unit=10),
            Pin(num='40',name='GPIOB_TXP02',func=pin_types.BIDIR,unit=10),
            Pin(num='41',name='GPIOB_TXN02',func=pin_types.BIDIR,unit=10),
            Pin(num='42',name='GPIOB_TXP04',func=pin_types.BIDIR,unit=10),
            Pin(num='43',name='GPIOB_TXN04',func=pin_types.BIDIR,unit=10),
            Pin(num='45',name='GPIOB_TXP06',func=pin_types.BIDIR,unit=10),
            Pin(num='46',name='GPIOB_TXN06',func=pin_types.BIDIR,unit=10),
            Pin(num='47',name='GPIOB_TXP09',func=pin_types.BIDIR,unit=10),
            Pin(num='48',name='GPIOB_TXN09',func=pin_types.BIDIR,unit=10),
            Pin(num='51',name='VCCIO4B',func=pin_types.PWRIN,unit=10),
            Pin(num='52',name='VCCIO4B',func=pin_types.PASSIVE,unit=10),
            Pin(num='53',name='GPIOB_TXP11',func=pin_types.BIDIR,unit=10),
            Pin(num='54',name='GPIOB_TXN11',func=pin_types.BIDIR,unit=10),
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=11),
            Pin(num='104',name='GND',func=pin_types.PASSIVE,unit=11),
            Pin(num='107',name='VCCA_TR',func=pin_types.PWRIN,unit=11),
            Pin(num='108',name='GND',func=pin_types.PASSIVE,unit=11),
            Pin(num='120',name='GND',func=pin_types.PASSIVE,unit=11),
            Pin(num='121',name='GND',func=pin_types.PASSIVE,unit=11),
            Pin(num='125',name='VCC',func=pin_types.PWRIN,unit=11),
            Pin(num='126',name='GND',func=pin_types.PASSIVE,unit=11),
            Pin(num='127',name='GND',func=pin_types.PASSIVE,unit=11),
            Pin(num='128',name='VCC',func=pin_types.PWRIN,unit=11),
            Pin(num='129',name='GND',func=pin_types.PASSIVE,unit=11),
            Pin(num='13',name='VCC',func=pin_types.PWRIN,unit=11),
            Pin(num='130',name='VCC',func=pin_types.PWRIN,unit=11),
            Pin(num='133',name='GND',func=pin_types.PASSIVE,unit=11),
            Pin(num='2',name='VCCA_TL',func=pin_types.PWRIN,unit=11),
            Pin(num='22',name='VCC',func=pin_types.PWRIN,unit=11),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=11),
            Pin(num='44',name='GND',func=pin_types.PASSIVE,unit=11),
            Pin(num='49',name='VCC',func=pin_types.PWRIN,unit=11),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=11),
            Pin(num='50',name='GND',func=pin_types.PASSIVE,unit=11),
            Pin(num='57',name='VCC',func=pin_types.PWRIN,unit=11),
            Pin(num='64',name='GND',func=pin_types.PASSIVE,unit=11),
            Pin(num='73',name='VCCA_BR',func=pin_types.PWRIN,unit=11),
            Pin(num='85',name='VCC',func=pin_types.PWRIN,unit=11),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=11),
            Pin(num='94',name='GND',func=pin_types.PASSIVE,unit=11),
            Pin(num='96',name='VCC',func=pin_types.PWRIN,unit=11)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['30', '28', '24', '25', '26', '27', '33', '34', '35', '29', '31', '32', '23']},{'label': 'uB', 'num': 2, 'pin_nums': ['18', '16', '14', '20', '17', '15', '19', '21']},{'label': 'uC', 'num': 3, 'pin_nums': ['10', '12', '7', '4', '11', '6', '8', '3']},{'label': 'uD', 'num': 4, 'pin_nums': ['136', '138', '140', '134', '131', '142', '144', '135', '137', '139', '141', '143', '132']},{'label': 'uE', 'num': 5, 'pin_nums': ['109', '111', '113', '115', '117', '119', '123', '110', '112', '114', '116', '118', '122', '124']},{'label': 'uF', 'num': 6, 'pin_nums': ['100', '102', '105', '93', '97', '99', '103', '106', '95', '98', '101']},{'label': 'uG', 'num': 7, 'pin_nums': ['81', '83', '82', '84', '87', '89', '90', '91', '92', '86']},{'label': 'uH', 'num': 8, 'pin_nums': ['88', '74', '76', '78', '77', '79', '80', '75']},{'label': 'uI', 'num': 9, 'pin_nums': ['56', '61', '66', '59', '63', '68', '70', '72', '55', '60', '58', '62', '65', '67', '69', '71']},{'label': 'uJ', 'num': 10, 'pin_nums': ['38', '42', '45', '47', '40', '51', '53', '36', '41', '39', '43', '46', '48', '52', '54']},{'label': 'uK', 'num': 11, 'pin_nums': ['2', '104', '125', '37', '127', '22', '73', '9', '1', '44', '85', '129', '128', '94', '5', '108', '107', '49', '120', '13', '50', '96', '133', '121', '130', '64', '57', '126']}] })])